pub struct DriverUnderTest<'a, D> { /* private fields */ }Expand description
This manages the driver under test’s lifecycle.
Implementations
Sourceimpl<'a, D: Driver> DriverUnderTest<'a, D>
impl<'a, D: Driver> DriverUnderTest<'a, D>
Sourcepub fn driver_outgoing(&self) -> &Incoming
pub fn driver_outgoing(&self) -> &Incoming
Allows the test to connect to capabilities that are provided by the driver through its outgoing namespace.
Sourcepub fn get_driver(&self) -> Option<&D>
pub fn get_driver(&self) -> Option<&D>
Returns a reference to the driver instance.
Sourcepub fn dispatcher(&self) -> WeakDispatcher
pub fn dispatcher(&self) -> WeakDispatcher
Gets the driver’s initial dispatcher.
Sourcepub fn node(&self) -> NodeHandle
pub fn node(&self) -> NodeHandle
Gets the TestNode that the driver-under-test is bound to.
Sourcepub fn harness(&self) -> &TestHarness<D>
pub fn harness(&self) -> &TestHarness<D>
Get a reference to the harness that started the driver.
Sourcepub async fn stop_driver(self)
pub async fn stop_driver(self)
Stop the driver.