pub trait FlexibleResultExt<T> {
// Required method
fn into_driver_result(self) -> Result<T, DriverError>;
}Expand description
Extension trait for fidl_next::FlexibleResult to convert it into a Result with DriverError.
Required Methods
Sourcefn into_driver_result(self) -> Result<T, DriverError>
fn into_driver_result(self) -> Result<T, DriverError>
Convert the flexible result into a Result with DriverError.